// Generated by gir (https://github.com/gtk-rs/gir @ 36917718ae60)
// from 
// from gir-files (https://github.com/gtk-rs/gir-files @ 6cef10cd64df)
// DO NOT EDIT

#include "manual.h"
#include <stdalign.h>
#include <stdio.h>

int main() {
    printf("%s;%zu;%zu\n", "PopplerAction", sizeof(PopplerAction), alignof(PopplerAction));
    printf("%s;%zu;%zu\n", "PopplerActionAny", sizeof(PopplerActionAny), alignof(PopplerActionAny));
    printf("%s;%zu;%zu\n", "PopplerActionGotoDest", sizeof(PopplerActionGotoDest), alignof(PopplerActionGotoDest));
    printf("%s;%zu;%zu\n", "PopplerActionGotoRemote", sizeof(PopplerActionGotoRemote), alignof(PopplerActionGotoRemote));
    printf("%s;%zu;%zu\n", "PopplerActionJavascript", sizeof(PopplerActionJavascript), alignof(PopplerActionJavascript));
    printf("%s;%zu;%zu\n", "PopplerActionLaunch", sizeof(PopplerActionLaunch), alignof(PopplerActionLaunch));
    printf("%s;%zu;%zu\n", "PopplerActionLayer", sizeof(PopplerActionLayer), alignof(PopplerActionLayer));
    printf("%s;%zu;%zu\n", "PopplerActionLayerAction", sizeof(PopplerActionLayerAction), alignof(PopplerActionLayerAction));
    printf("%s;%zu;%zu\n", "PopplerActionMovie", sizeof(PopplerActionMovie), alignof(PopplerActionMovie));
    printf("%s;%zu;%zu\n", "PopplerActionMovieOperation", sizeof(PopplerActionMovieOperation), alignof(PopplerActionMovieOperation));
    printf("%s;%zu;%zu\n", "PopplerActionNamed", sizeof(PopplerActionNamed), alignof(PopplerActionNamed));
    printf("%s;%zu;%zu\n", "PopplerActionOCGState", sizeof(PopplerActionOCGState), alignof(PopplerActionOCGState));
    printf("%s;%zu;%zu\n", "PopplerActionRendition", sizeof(PopplerActionRendition), alignof(PopplerActionRendition));
    printf("%s;%zu;%zu\n", "PopplerActionResetForm", sizeof(PopplerActionResetForm), alignof(PopplerActionResetForm));
    printf("%s;%zu;%zu\n", "PopplerActionType", sizeof(PopplerActionType), alignof(PopplerActionType));
    printf("%s;%zu;%zu\n", "PopplerActionUri", sizeof(PopplerActionUri), alignof(PopplerActionUri));
    printf("%s;%zu;%zu\n", "PopplerAdditionalActionType", sizeof(PopplerAdditionalActionType), alignof(PopplerAdditionalActionType));
    printf("%s;%zu;%zu\n", "PopplerAnnotCalloutLine", sizeof(PopplerAnnotCalloutLine), alignof(PopplerAnnotCalloutLine));
    printf("%s;%zu;%zu\n", "PopplerAnnotExternalDataType", sizeof(PopplerAnnotExternalDataType), alignof(PopplerAnnotExternalDataType));
    printf("%s;%zu;%zu\n", "PopplerAnnotFlag", sizeof(PopplerAnnotFlag), alignof(PopplerAnnotFlag));
    printf("%s;%zu;%zu\n", "PopplerAnnotFreeTextQuadding", sizeof(PopplerAnnotFreeTextQuadding), alignof(PopplerAnnotFreeTextQuadding));
    printf("%s;%zu;%zu\n", "PopplerAnnotMapping", sizeof(PopplerAnnotMapping), alignof(PopplerAnnotMapping));
    printf("%s;%zu;%zu\n", "PopplerAnnotMarkupReplyType", sizeof(PopplerAnnotMarkupReplyType), alignof(PopplerAnnotMarkupReplyType));
    printf("%s;%zu;%zu\n", "PopplerAnnotStampIcon", sizeof(PopplerAnnotStampIcon), alignof(PopplerAnnotStampIcon));
    printf("%s;%zu;%zu\n", "PopplerAnnotTextState", sizeof(PopplerAnnotTextState), alignof(PopplerAnnotTextState));
    printf("%s;%zu;%zu\n", "PopplerAnnotType", sizeof(PopplerAnnotType), alignof(PopplerAnnotType));
    printf("%s;%zu;%zu\n", "PopplerAttachment", sizeof(PopplerAttachment), alignof(PopplerAttachment));
    printf("%s;%zu;%zu\n", "PopplerAttachmentClass", sizeof(PopplerAttachmentClass), alignof(PopplerAttachmentClass));
    printf("%s;%zu;%zu\n", "PopplerBackend", sizeof(PopplerBackend), alignof(PopplerBackend));
    printf("%s;%zu;%zu\n", "PopplerCertificateStatus", sizeof(PopplerCertificateStatus), alignof(PopplerCertificateStatus));
    printf("%s;%zu;%zu\n", "PopplerColor", sizeof(PopplerColor), alignof(PopplerColor));
    printf("%s;%zu;%zu\n", "PopplerDestType", sizeof(PopplerDestType), alignof(PopplerDestType));
    printf("%s;%zu;%zu\n", "PopplerError", sizeof(PopplerError), alignof(PopplerError));
    printf("%s;%zu;%zu\n", "PopplerFindFlags", sizeof(PopplerFindFlags), alignof(PopplerFindFlags));
    printf("%s;%zu;%zu\n", "PopplerFontDescription", sizeof(PopplerFontDescription), alignof(PopplerFontDescription));
    printf("%s;%zu;%zu\n", "PopplerFontType", sizeof(PopplerFontType), alignof(PopplerFontType));
    printf("%s;%zu;%zu\n", "PopplerFormButtonType", sizeof(PopplerFormButtonType), alignof(PopplerFormButtonType));
    printf("%s;%zu;%zu\n", "PopplerFormChoiceType", sizeof(PopplerFormChoiceType), alignof(PopplerFormChoiceType));
    printf("%s;%zu;%zu\n", "PopplerFormFieldMapping", sizeof(PopplerFormFieldMapping), alignof(PopplerFormFieldMapping));
    printf("%s;%zu;%zu\n", "PopplerFormFieldType", sizeof(PopplerFormFieldType), alignof(PopplerFormFieldType));
    printf("%s;%zu;%zu\n", "PopplerFormTextType", sizeof(PopplerFormTextType), alignof(PopplerFormTextType));
    printf("%s;%zu;%zu\n", "PopplerImageMapping", sizeof(PopplerImageMapping), alignof(PopplerImageMapping));
    printf("%s;%zu;%zu\n", "PopplerLinkMapping", sizeof(PopplerLinkMapping), alignof(PopplerLinkMapping));
    printf("%s;%zu;%zu\n", "PopplerMoviePlayMode", sizeof(PopplerMoviePlayMode), alignof(PopplerMoviePlayMode));
    printf("%s;%zu;%zu\n", "PopplerPDFConformance", sizeof(PopplerPDFConformance), alignof(PopplerPDFConformance));
    printf("%s;%zu;%zu\n", "PopplerPDFPart", sizeof(PopplerPDFPart), alignof(PopplerPDFPart));
    printf("%s;%zu;%zu\n", "PopplerPDFSubtype", sizeof(PopplerPDFSubtype), alignof(PopplerPDFSubtype));
    printf("%s;%zu;%zu\n", "PopplerPageLayout", sizeof(PopplerPageLayout), alignof(PopplerPageLayout));
    printf("%s;%zu;%zu\n", "PopplerPageMode", sizeof(PopplerPageMode), alignof(PopplerPageMode));
    printf("%s;%zu;%zu\n", "PopplerPageRange", sizeof(PopplerPageRange), alignof(PopplerPageRange));
    printf("%s;%zu;%zu\n", "PopplerPageTransition", sizeof(PopplerPageTransition), alignof(PopplerPageTransition));
    printf("%s;%zu;%zu\n", "PopplerPageTransitionAlignment", sizeof(PopplerPageTransitionAlignment), alignof(PopplerPageTransitionAlignment));
    printf("%s;%zu;%zu\n", "PopplerPageTransitionDirection", sizeof(PopplerPageTransitionDirection), alignof(PopplerPageTransitionDirection));
    printf("%s;%zu;%zu\n", "PopplerPageTransitionType", sizeof(PopplerPageTransitionType), alignof(PopplerPageTransitionType));
    printf("%s;%zu;%zu\n", "PopplerPermissions", sizeof(PopplerPermissions), alignof(PopplerPermissions));
    printf("%s;%zu;%zu\n", "PopplerPoint", sizeof(PopplerPoint), alignof(PopplerPoint));
    printf("%s;%zu;%zu\n", "PopplerPrintDuplex", sizeof(PopplerPrintDuplex), alignof(PopplerPrintDuplex));
    printf("%s;%zu;%zu\n", "PopplerPrintFlags", sizeof(PopplerPrintFlags), alignof(PopplerPrintFlags));
    printf("%s;%zu;%zu\n", "PopplerPrintScaling", sizeof(PopplerPrintScaling), alignof(PopplerPrintScaling));
    printf("%s;%zu;%zu\n", "PopplerQuadrilateral", sizeof(PopplerQuadrilateral), alignof(PopplerQuadrilateral));
    printf("%s;%zu;%zu\n", "PopplerRectangle", sizeof(PopplerRectangle), alignof(PopplerRectangle));
    printf("%s;%zu;%zu\n", "PopplerRenderAnnotsFlags", sizeof(PopplerRenderAnnotsFlags), alignof(PopplerRenderAnnotsFlags));
    printf("%s;%zu;%zu\n", "PopplerSelectionStyle", sizeof(PopplerSelectionStyle), alignof(PopplerSelectionStyle));
    printf("%s;%zu;%zu\n", "PopplerSignatureStatus", sizeof(PopplerSignatureStatus), alignof(PopplerSignatureStatus));
    printf("%s;%zu;%zu\n", "PopplerSignatureValidationFlags", sizeof(PopplerSignatureValidationFlags), alignof(PopplerSignatureValidationFlags));
    printf("%s;%zu;%zu\n", "PopplerStretch", sizeof(PopplerStretch), alignof(PopplerStretch));
    printf("%s;%zu;%zu\n", "PopplerStructureBlockAlign", sizeof(PopplerStructureBlockAlign), alignof(PopplerStructureBlockAlign));
    printf("%s;%zu;%zu\n", "PopplerStructureBorderStyle", sizeof(PopplerStructureBorderStyle), alignof(PopplerStructureBorderStyle));
    printf("%s;%zu;%zu\n", "PopplerStructureElementKind", sizeof(PopplerStructureElementKind), alignof(PopplerStructureElementKind));
    printf("%s;%zu;%zu\n", "PopplerStructureFormRole", sizeof(PopplerStructureFormRole), alignof(PopplerStructureFormRole));
    printf("%s;%zu;%zu\n", "PopplerStructureFormState", sizeof(PopplerStructureFormState), alignof(PopplerStructureFormState));
    printf("%s;%zu;%zu\n", "PopplerStructureGetTextFlags", sizeof(PopplerStructureGetTextFlags), alignof(PopplerStructureGetTextFlags));
    printf("%s;%zu;%zu\n", "PopplerStructureGlyphOrientation", sizeof(PopplerStructureGlyphOrientation), alignof(PopplerStructureGlyphOrientation));
    printf("%s;%zu;%zu\n", "PopplerStructureInlineAlign", sizeof(PopplerStructureInlineAlign), alignof(PopplerStructureInlineAlign));
    printf("%s;%zu;%zu\n", "PopplerStructureListNumbering", sizeof(PopplerStructureListNumbering), alignof(PopplerStructureListNumbering));
    printf("%s;%zu;%zu\n", "PopplerStructurePlacement", sizeof(PopplerStructurePlacement), alignof(PopplerStructurePlacement));
    printf("%s;%zu;%zu\n", "PopplerStructureRubyAlign", sizeof(PopplerStructureRubyAlign), alignof(PopplerStructureRubyAlign));
    printf("%s;%zu;%zu\n", "PopplerStructureRubyPosition", sizeof(PopplerStructureRubyPosition), alignof(PopplerStructureRubyPosition));
    printf("%s;%zu;%zu\n", "PopplerStructureTableScope", sizeof(PopplerStructureTableScope), alignof(PopplerStructureTableScope));
    printf("%s;%zu;%zu\n", "PopplerStructureTextAlign", sizeof(PopplerStructureTextAlign), alignof(PopplerStructureTextAlign));
    printf("%s;%zu;%zu\n", "PopplerStructureTextDecoration", sizeof(PopplerStructureTextDecoration), alignof(PopplerStructureTextDecoration));
    printf("%s;%zu;%zu\n", "PopplerStructureWritingMode", sizeof(PopplerStructureWritingMode), alignof(PopplerStructureWritingMode));
    printf("%s;%zu;%zu\n", "PopplerStyle", sizeof(PopplerStyle), alignof(PopplerStyle));
    printf("%s;%zu;%zu\n", "PopplerTextAttributes", sizeof(PopplerTextAttributes), alignof(PopplerTextAttributes));
    printf("%s;%zu;%zu\n", "PopplerViewerPreferences", sizeof(PopplerViewerPreferences), alignof(PopplerViewerPreferences));
    printf("%s;%zu;%zu\n", "PopplerWeight", sizeof(PopplerWeight), alignof(PopplerWeight));
    return 0;
}
