// Generated by gir (https://github.com/gtk-rs/gir @ 36917718ae60)
// from 
// from gir-files (https://github.com/gtk-rs/gir-files @ 6cef10cd64df)
// DO NOT EDIT

#include "manual.h"
#include <stdio.h>

#define PRINT_CONSTANT(CONSTANT_NAME) \
    printf("%s;", #CONSTANT_NAME); \
    printf(_Generic((CONSTANT_NAME), \
                    char *: "%s", \
                    const char *: "%s", \
                    char: "%c", \
                    signed char: "%hhd", \
                    unsigned char: "%hhu", \
                    short int: "%hd", \
                    unsigned short int: "%hu", \
                    int: "%d", \
                    unsigned int: "%u", \
                    long: "%ld", \
                    unsigned long: "%lu", \
                    long long: "%lld", \
                    unsigned long long: "%llu", \
                    float: "%.6f", \
                    double: "%.6f", \
                    long double: "%ld"), \
           CONSTANT_NAME); \
    printf("\n");

int main() {
    PRINT_CONSTANT((gint) POPPLER_ACTION_GOTO_DEST);
    PRINT_CONSTANT((gint) POPPLER_ACTION_GOTO_REMOTE);
    PRINT_CONSTANT((gint) POPPLER_ACTION_JAVASCRIPT);
    PRINT_CONSTANT((gint) POPPLER_ACTION_LAUNCH);
    PRINT_CONSTANT((gint) POPPLER_ACTION_LAYER_OFF);
    PRINT_CONSTANT((gint) POPPLER_ACTION_LAYER_ON);
    PRINT_CONSTANT((gint) POPPLER_ACTION_LAYER_TOGGLE);
    PRINT_CONSTANT((gint) POPPLER_ACTION_MOVIE);
    PRINT_CONSTANT((gint) POPPLER_ACTION_MOVIE_PAUSE);
    PRINT_CONSTANT((gint) POPPLER_ACTION_MOVIE_PLAY);
    PRINT_CONSTANT((gint) POPPLER_ACTION_MOVIE_RESUME);
    PRINT_CONSTANT((gint) POPPLER_ACTION_MOVIE_STOP);
    PRINT_CONSTANT((gint) POPPLER_ACTION_NAMED);
    PRINT_CONSTANT((gint) POPPLER_ACTION_NONE);
    PRINT_CONSTANT((gint) POPPLER_ACTION_OCG_STATE);
    PRINT_CONSTANT((gint) POPPLER_ACTION_RENDITION);
    PRINT_CONSTANT((gint) POPPLER_ACTION_RESET_FORM);
    PRINT_CONSTANT((gint) POPPLER_ACTION_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_ACTION_URI);
    PRINT_CONSTANT((gint) POPPLER_ADDITIONAL_ACTION_CALCULATE_FIELD);
    PRINT_CONSTANT((gint) POPPLER_ADDITIONAL_ACTION_FIELD_MODIFIED);
    PRINT_CONSTANT((gint) POPPLER_ADDITIONAL_ACTION_FORMAT_FIELD);
    PRINT_CONSTANT((gint) POPPLER_ADDITIONAL_ACTION_VALIDATE_FIELD);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_3D);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_CARET);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_CIRCLE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_EXTERNAL_DATA_MARKUP_3D);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_EXTERNAL_DATA_MARKUP_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_FILE_ATTACHMENT);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_HIDDEN);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_INVISIBLE);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_LOCKED);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_LOCKED_CONTENTS);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_NO_ROTATE);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_NO_VIEW);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_NO_ZOOM);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_PRINT);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_READ_ONLY);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_TOGGLE_NO_VIEW);
    PRINT_CONSTANT((guint) POPPLER_ANNOT_FLAG_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_FREE_TEXT);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_FREE_TEXT_QUADDING_CENTERED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_FREE_TEXT_QUADDING_LEFT_JUSTIFIED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_FREE_TEXT_QUADDING_RIGHT_JUSTIFIED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_HIGHLIGHT);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_INK);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_LINE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_LINK);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_MARKUP_REPLY_TYPE_GROUP);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_MARKUP_REPLY_TYPE_R);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_MOVIE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_POLYGON);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_POLY_LINE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_POPUP);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_PRINTER_MARK);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_SCREEN);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_SOUND);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_SQUARE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_SQUIGGLY);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_APPROVED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_AS_IS);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_CONFIDENTIAL);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_DEPARTMENTAL);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_EXPERIMENTAL);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_EXPIRED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_FINAL);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_FOR_COMMENT);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_FOR_PUBLIC_RELEASE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_NONE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_NOT_APPROVED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_NOT_FOR_PUBLIC_RELEASE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_SOLD);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_TOP_SECRET);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STAMP_ICON_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_STRIKE_OUT);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TEXT);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_CHECK);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_CIRCLE);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_COMMENT);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_CROSS);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_CROSS_HAIRS);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_HELP);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_INSERT);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_KEY);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_NEW_PARAGRAPH);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_NOTE);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_PARAGRAPH);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_RIGHT_ARROW);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_RIGHT_POINTER);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_STAR);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_UP_ARROW);
    PRINT_CONSTANT(POPPLER_ANNOT_TEXT_ICON_UP_LEFT_ARROW);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TEXT_STATE_ACCEPTED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TEXT_STATE_CANCELLED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TEXT_STATE_COMPLETED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TEXT_STATE_MARKED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TEXT_STATE_NONE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TEXT_STATE_REJECTED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TEXT_STATE_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TEXT_STATE_UNMARKED);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_TRAP_NET);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_UNDERLINE);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_WATERMARK);
    PRINT_CONSTANT((gint) POPPLER_ANNOT_WIDGET);
    PRINT_CONSTANT((gint) POPPLER_BACKEND_CAIRO);
    PRINT_CONSTANT((gint) POPPLER_BACKEND_SPLASH);
    PRINT_CONSTANT((gint) POPPLER_BACKEND_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_CERTIFICATE_EXPIRED);
    PRINT_CONSTANT((gint) POPPLER_CERTIFICATE_GENERIC_ERROR);
    PRINT_CONSTANT((gint) POPPLER_CERTIFICATE_NOT_VERIFIED);
    PRINT_CONSTANT((gint) POPPLER_CERTIFICATE_REVOKED);
    PRINT_CONSTANT((gint) POPPLER_CERTIFICATE_TRUSTED);
    PRINT_CONSTANT((gint) POPPLER_CERTIFICATE_UNKNOWN_ISSUER);
    PRINT_CONSTANT((gint) POPPLER_CERTIFICATE_UNTRUSTED_ISSUER);
    PRINT_CONSTANT((gint) POPPLER_DEST_FIT);
    PRINT_CONSTANT((gint) POPPLER_DEST_FITB);
    PRINT_CONSTANT((gint) POPPLER_DEST_FITBH);
    PRINT_CONSTANT((gint) POPPLER_DEST_FITBV);
    PRINT_CONSTANT((gint) POPPLER_DEST_FITH);
    PRINT_CONSTANT((gint) POPPLER_DEST_FITR);
    PRINT_CONSTANT((gint) POPPLER_DEST_FITV);
    PRINT_CONSTANT((gint) POPPLER_DEST_NAMED);
    PRINT_CONSTANT((gint) POPPLER_DEST_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_DEST_XYZ);
    PRINT_CONSTANT((gint) POPPLER_ERROR_BAD_CATALOG);
    PRINT_CONSTANT((gint) POPPLER_ERROR_DAMAGED);
    PRINT_CONSTANT((gint) POPPLER_ERROR_ENCRYPTED);
    PRINT_CONSTANT((gint) POPPLER_ERROR_INVALID);
    PRINT_CONSTANT((gint) POPPLER_ERROR_OPEN_FILE);
    PRINT_CONSTANT((gint) POPPLER_ERROR_SIGNING);
    PRINT_CONSTANT((guint) POPPLER_FIND_BACKWARDS);
    PRINT_CONSTANT((guint) POPPLER_FIND_CASE_SENSITIVE);
    PRINT_CONSTANT((guint) POPPLER_FIND_DEFAULT);
    PRINT_CONSTANT((guint) POPPLER_FIND_IGNORE_DIACRITICS);
    PRINT_CONSTANT((guint) POPPLER_FIND_MULTILINE);
    PRINT_CONSTANT((guint) POPPLER_FIND_WHOLE_WORDS_ONLY);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_CID_TYPE0);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_CID_TYPE0C);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_CID_TYPE0COT);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_CID_TYPE2);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_CID_TYPE2OT);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_TRUETYPE);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_TRUETYPEOT);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_TYPE1);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_TYPE1C);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_TYPE1COT);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_TYPE3);
    PRINT_CONSTANT((gint) POPPLER_FONT_TYPE_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_FORM_BUTTON_CHECK);
    PRINT_CONSTANT((gint) POPPLER_FORM_BUTTON_PUSH);
    PRINT_CONSTANT((gint) POPPLER_FORM_BUTTON_RADIO);
    PRINT_CONSTANT((gint) POPPLER_FORM_CHOICE_COMBO);
    PRINT_CONSTANT((gint) POPPLER_FORM_CHOICE_LIST);
    PRINT_CONSTANT((gint) POPPLER_FORM_FIELD_BUTTON);
    PRINT_CONSTANT((gint) POPPLER_FORM_FIELD_CHOICE);
    PRINT_CONSTANT((gint) POPPLER_FORM_FIELD_SIGNATURE);
    PRINT_CONSTANT((gint) POPPLER_FORM_FIELD_TEXT);
    PRINT_CONSTANT((gint) POPPLER_FORM_FIELD_UNKNOWN);
    PRINT_CONSTANT((gint) POPPLER_FORM_TEXT_FILE_SELECT);
    PRINT_CONSTANT((gint) POPPLER_FORM_TEXT_MULTILINE);
    PRINT_CONSTANT((gint) POPPLER_FORM_TEXT_NORMAL);
    PRINT_CONSTANT(POPPLER_HAS_CAIRO);
    PRINT_CONSTANT((gint) POPPLER_MOVIE_PLAY_MODE_ONCE);
    PRINT_CONSTANT((gint) POPPLER_MOVIE_PLAY_MODE_OPEN);
    PRINT_CONSTANT((gint) POPPLER_MOVIE_PLAY_MODE_PALINDROME);
    PRINT_CONSTANT((gint) POPPLER_MOVIE_PLAY_MODE_REPEAT);
    PRINT_CONSTANT((gint) POPPLER_PAGE_LAYOUT_ONE_COLUMN);
    PRINT_CONSTANT((gint) POPPLER_PAGE_LAYOUT_SINGLE_PAGE);
    PRINT_CONSTANT((gint) POPPLER_PAGE_LAYOUT_TWO_COLUMN_LEFT);
    PRINT_CONSTANT((gint) POPPLER_PAGE_LAYOUT_TWO_COLUMN_RIGHT);
    PRINT_CONSTANT((gint) POPPLER_PAGE_LAYOUT_TWO_PAGE_LEFT);
    PRINT_CONSTANT((gint) POPPLER_PAGE_LAYOUT_TWO_PAGE_RIGHT);
    PRINT_CONSTANT((gint) POPPLER_PAGE_LAYOUT_UNSET);
    PRINT_CONSTANT((gint) POPPLER_PAGE_MODE_FULL_SCREEN);
    PRINT_CONSTANT((gint) POPPLER_PAGE_MODE_NONE);
    PRINT_CONSTANT((gint) POPPLER_PAGE_MODE_UNSET);
    PRINT_CONSTANT((gint) POPPLER_PAGE_MODE_USE_ATTACHMENTS);
    PRINT_CONSTANT((gint) POPPLER_PAGE_MODE_USE_OC);
    PRINT_CONSTANT((gint) POPPLER_PAGE_MODE_USE_OUTLINES);
    PRINT_CONSTANT((gint) POPPLER_PAGE_MODE_USE_THUMBS);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_BLINDS);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_BOX);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_COVER);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_DISSOLVE);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_FADE);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_FLY);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_GLITTER);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_HORIZONTAL);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_INWARD);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_OUTWARD);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_PUSH);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_REPLACE);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_SPLIT);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_UNCOVER);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_VERTICAL);
    PRINT_CONSTANT((gint) POPPLER_PAGE_TRANSITION_WIPE);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_CONF_A);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_CONF_B);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_CONF_G);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_CONF_N);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_CONF_NONE);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_CONF_P);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_CONF_PG);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_CONF_U);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_CONF_UNSET);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_NONE);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_1);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_2);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_3);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_4);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_5);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_6);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_7);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_8);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_NONE);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PART_UNSET);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PDF_A);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PDF_E);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PDF_UA);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PDF_VT);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_PDF_X);
    PRINT_CONSTANT((gint) POPPLER_PDF_SUBTYPE_UNSET);
    PRINT_CONSTANT((guint) POPPLER_PERMISSIONS_FULL);
    PRINT_CONSTANT((guint) POPPLER_PERMISSIONS_OK_TO_ADD_NOTES);
    PRINT_CONSTANT((guint) POPPLER_PERMISSIONS_OK_TO_ASSEMBLE);
    PRINT_CONSTANT((guint) POPPLER_PERMISSIONS_OK_TO_COPY);
    PRINT_CONSTANT((guint) POPPLER_PERMISSIONS_OK_TO_EXTRACT_CONTENTS);
    PRINT_CONSTANT((guint) POPPLER_PERMISSIONS_OK_TO_FILL_FORM);
    PRINT_CONSTANT((guint) POPPLER_PERMISSIONS_OK_TO_MODIFY);
    PRINT_CONSTANT((guint) POPPLER_PERMISSIONS_OK_TO_PRINT);
    PRINT_CONSTANT((guint) POPPLER_PERMISSIONS_OK_TO_PRINT_HIGH_RESOLUTION);
    PRINT_CONSTANT((guint) POPPLER_PRINT_ALL);
    PRINT_CONSTANT((guint) POPPLER_PRINT_DOCUMENT);
    PRINT_CONSTANT((gint) POPPLER_PRINT_DUPLEX_DUPLEX_FLIP_LONG_EDGE);
    PRINT_CONSTANT((gint) POPPLER_PRINT_DUPLEX_DUPLEX_FLIP_SHORT_EDGE);
    PRINT_CONSTANT((gint) POPPLER_PRINT_DUPLEX_NONE);
    PRINT_CONSTANT((gint) POPPLER_PRINT_DUPLEX_SIMPLEX);
    PRINT_CONSTANT((guint) POPPLER_PRINT_MARKUP_ANNOTS);
    PRINT_CONSTANT((gint) POPPLER_PRINT_SCALING_APP_DEFAULT);
    PRINT_CONSTANT((gint) POPPLER_PRINT_SCALING_NONE);
    PRINT_CONSTANT((guint) POPPLER_PRINT_STAMP_ANNOTS_ONLY);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_3D);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_ALL);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_CARET);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_CIRCLE);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_FILEATTACHMENT);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_FREETEXT);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_HIGHLIGHT);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_INK);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_LINE);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_LINK);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_MOVIE);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_NONE);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_POLYGON);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_POLYLINE);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_POPUP);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_PRINTERMARK);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_PRINT_ALL);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_PRINT_DOCUMENT);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_PRINT_MARKUP);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_PRINT_STAMP);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_RICHMEDIA);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_SCREEN);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_SOUND);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_SQUARE);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_SQUIGGLY);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_STAMP);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_STRIKEOUT);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_TEXT);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_TRAPNET);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_UNDERLINE);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_WATERMARK);
    PRINT_CONSTANT((guint) POPPLER_RENDER_ANNOTS_WIDGET);
    PRINT_CONSTANT((gint) POPPLER_SELECTION_GLYPH);
    PRINT_CONSTANT((gint) POPPLER_SELECTION_LINE);
    PRINT_CONSTANT((gint) POPPLER_SELECTION_WORD);
    PRINT_CONSTANT((gint) POPPLER_SIGNATURE_DECODING_ERROR);
    PRINT_CONSTANT((gint) POPPLER_SIGNATURE_DIGEST_MISMATCH);
    PRINT_CONSTANT((gint) POPPLER_SIGNATURE_GENERIC_ERROR);
    PRINT_CONSTANT((gint) POPPLER_SIGNATURE_INVALID);
    PRINT_CONSTANT((gint) POPPLER_SIGNATURE_NOT_FOUND);
    PRINT_CONSTANT((gint) POPPLER_SIGNATURE_NOT_VERIFIED);
    PRINT_CONSTANT((gint) POPPLER_SIGNATURE_VALID);
    PRINT_CONSTANT((guint) POPPLER_SIGNATURE_VALIDATION_FLAG_USE_AIA_CERTIFICATE_FETCH);
    PRINT_CONSTANT((guint) POPPLER_SIGNATURE_VALIDATION_FLAG_VALIDATE_CERTIFICATE);
    PRINT_CONSTANT((guint) POPPLER_SIGNATURE_VALIDATION_FLAG_WITHOUT_OCSP_REVOCATION_CHECK);
    PRINT_CONSTANT((gint) POPPLER_STRETCH_CONDENSED);
    PRINT_CONSTANT((gint) POPPLER_STRETCH_EXPANDED);
    PRINT_CONSTANT((gint) POPPLER_STRETCH_EXTRA_CONDENSED);
    PRINT_CONSTANT((gint) POPPLER_STRETCH_EXTRA_EXPANDED);
    PRINT_CONSTANT((gint) POPPLER_STRETCH_NORMAL);
    PRINT_CONSTANT((gint) POPPLER_STRETCH_SEMI_CONDENSED);
    PRINT_CONSTANT((gint) POPPLER_STRETCH_SEMI_EXPANDED);
    PRINT_CONSTANT((gint) POPPLER_STRETCH_ULTRA_CONDENSED);
    PRINT_CONSTANT((gint) POPPLER_STRETCH_ULTRA_EXPANDED);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BLOCK_ALIGN_AFTER);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BLOCK_ALIGN_BEFORE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BLOCK_ALIGN_JUSTIFY);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BLOCK_ALIGN_MIDDLE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BORDER_STYLE_DASHED);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BORDER_STYLE_DOTTED);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BORDER_STYLE_DOUBLE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BORDER_STYLE_GROOVE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BORDER_STYLE_HIDDEN);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BORDER_STYLE_INSET);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BORDER_STYLE_NONE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BORDER_STYLE_OUTSET);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_BORDER_STYLE_SOLID);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_ANNOT);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_ARTICLE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_BIBENTRY);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_BLOCKQUOTE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_CAPTION);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_CODE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_CONTENT);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_DIV);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_DOCUMENT);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_FIGURE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_FORM);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_FORMULA);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_HEADING);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_HEADING_1);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_HEADING_2);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_HEADING_3);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_HEADING_4);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_HEADING_5);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_HEADING_6);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_INDEX);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_LINK);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_LIST);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_LIST_BODY);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_LIST_ITEM);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_LIST_LABEL);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_NONSTRUCT);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_NOTE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_OBJECT_REFERENCE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_PARAGRAPH);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_PART);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_PRIVATE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_QUOTE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_REFERENCE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_RUBY);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_RUBY_ANNOT_TEXT);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_RUBY_BASE_TEXT);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_RUBY_PUNCTUATION);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_SECTION);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_SPAN);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_TABLE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_TABLE_BODY);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_TABLE_DATA);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_TABLE_FOOTER);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_TABLE_HEADER);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_TABLE_HEADING);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_TABLE_ROW);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_TOC);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_TOC_ITEM);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_WARICHU);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_WARICHU_PUNCTUATION);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_ELEMENT_WARICHU_TEXT);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_FORM_ROLE_CHECKBOX);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_FORM_ROLE_PUSH_BUTTON);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_FORM_ROLE_RADIO_BUTTON);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_FORM_ROLE_TEXT_VALUE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_FORM_ROLE_UNDEFINED);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_FORM_STATE_NEUTRAL);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_FORM_STATE_OFF);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_FORM_STATE_ON);
    PRINT_CONSTANT((guint) POPPLER_STRUCTURE_GET_TEXT_NONE);
    PRINT_CONSTANT((guint) POPPLER_STRUCTURE_GET_TEXT_RECURSIVE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_GLYPH_ORIENTATION_0);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_GLYPH_ORIENTATION_180);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_GLYPH_ORIENTATION_270);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_GLYPH_ORIENTATION_90);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_GLYPH_ORIENTATION_AUTO);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_INLINE_ALIGN_CENTER);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_INLINE_ALIGN_END);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_INLINE_ALIGN_START);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_LIST_NUMBERING_CIRCLE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_LIST_NUMBERING_DECIMAL);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_LIST_NUMBERING_DISC);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_LIST_NUMBERING_LOWER_ALPHA);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_LIST_NUMBERING_LOWER_ROMAN);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_LIST_NUMBERING_NONE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_LIST_NUMBERING_SQUARE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_LIST_NUMBERING_UPPER_ALPHA);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_LIST_NUMBERING_UPPER_ROMAN);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_PLACEMENT_BEFORE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_PLACEMENT_BLOCK);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_PLACEMENT_END);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_PLACEMENT_INLINE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_PLACEMENT_START);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_RUBY_ALIGN_CENTER);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_RUBY_ALIGN_DISTRIBUTE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_RUBY_ALIGN_END);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_RUBY_ALIGN_JUSTIFY);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_RUBY_ALIGN_START);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_RUBY_POSITION_AFTER);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_RUBY_POSITION_BEFORE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_RUBY_POSITION_INLINE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_RUBY_POSITION_WARICHU);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TABLE_SCOPE_BOTH);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TABLE_SCOPE_COLUMN);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TABLE_SCOPE_ROW);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TEXT_ALIGN_CENTER);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TEXT_ALIGN_END);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TEXT_ALIGN_JUSTIFY);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TEXT_ALIGN_START);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TEXT_DECORATION_LINETHROUGH);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TEXT_DECORATION_NONE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TEXT_DECORATION_OVERLINE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_TEXT_DECORATION_UNDERLINE);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_WRITING_MODE_LR_TB);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_WRITING_MODE_RL_TB);
    PRINT_CONSTANT((gint) POPPLER_STRUCTURE_WRITING_MODE_TB_RL);
    PRINT_CONSTANT((gint) POPPLER_STYLE_ITALIC);
    PRINT_CONSTANT((gint) POPPLER_STYLE_NORMAL);
    PRINT_CONSTANT((gint) POPPLER_STYLE_OBLIQUE);
    PRINT_CONSTANT((guint) POPPLER_VIEWER_PREFERENCES_CENTER_WINDOW);
    PRINT_CONSTANT((guint) POPPLER_VIEWER_PREFERENCES_DIRECTION_RTL);
    PRINT_CONSTANT((guint) POPPLER_VIEWER_PREFERENCES_DISPLAY_DOC_TITLE);
    PRINT_CONSTANT((guint) POPPLER_VIEWER_PREFERENCES_FIT_WINDOW);
    PRINT_CONSTANT((guint) POPPLER_VIEWER_PREFERENCES_HIDE_MENUBAR);
    PRINT_CONSTANT((guint) POPPLER_VIEWER_PREFERENCES_HIDE_TOOLBAR);
    PRINT_CONSTANT((guint) POPPLER_VIEWER_PREFERENCES_HIDE_WINDOWUI);
    PRINT_CONSTANT((guint) POPPLER_VIEWER_PREFERENCES_UNSET);
    PRINT_CONSTANT((gint) POPPLER_WEIGHT_BOLD);
    PRINT_CONSTANT((gint) POPPLER_WEIGHT_HEAVY);
    PRINT_CONSTANT((gint) POPPLER_WEIGHT_LIGHT);
    PRINT_CONSTANT((gint) POPPLER_WEIGHT_MEDIUM);
    PRINT_CONSTANT((gint) POPPLER_WEIGHT_NORMAL);
    PRINT_CONSTANT((gint) POPPLER_WEIGHT_SEMIBOLD);
    PRINT_CONSTANT((gint) POPPLER_WEIGHT_THIN);
    PRINT_CONSTANT((gint) POPPLER_WEIGHT_ULTRABOLD);
    PRINT_CONSTANT((gint) POPPLER_WEIGHT_ULTRALIGHT);
    return 0;
}
